==> qore-0.9.10.tar.bz2: qore-0.9.10/docs/lang/html/navtreeindex15.js <==
var NAVTREEINDEX15 =
{
"release_notes.html#qore_0812":[0,73,21],
"release_notes.html#qore_0812":[0,36,21],
"release_notes.html#qore_08121":[0,73,20],
"release_notes.html#qore_08121":[0,36,20],
"release_notes.html#qore_081210":[0,36,11],
"release_notes.html#qore_081210":[0,73,11],
"release_notes.html#qore_081210_bug_fixes":[0,36,11,0],
"release_notes.html#qore_081210_bug_fixes":[0,73,11,0],
"release_notes.html#qore_081211":[0,36,10],
"release_notes.html#qore_081211":[0,73,10],
"release_notes.html#qore_081211_bug_fixes":[0,36,10,1],
"release_notes.html#qore_081211_bug_fixes":[0,73,10,1],
"release_notes.html#qore_081211_new_features":[0,73,10,0],
"release_notes.html#qore_081211_new_features":[0,36,10,0],
"release_notes.html#qore_081212":[0,73,9],
"release_notes.html#qore_081212":[0,36,9],
"release_notes.html#qore_081212_bug_fixes":[0,73,9,1],
"release_notes.html#qore_081212_bug_fixes":[0,36,9,1],
"release_notes.html#qore_081212_new_features":[0,73,9,0],
"release_notes.html#qore_081212_new_features":[0,36,9,0],
"release_notes.html#qore_08121_bug_fixes":[0,73,20,0],
"release_notes.html#qore_08121_bug_fixes":[0,36,20,0],
"release_notes.html#qore_08122":[0,36,19],
"release_notes.html#qore_08122":[0,73,19],
"release_notes.html#qore_08122_bug_fixes":[0,73,19,0],
"release_notes.html#qore_08122_bug_fixes":[0,36,19,0],
"release_notes.html#qore_08123":[0,73,18],
"release_notes.html#qore_08123":[0,36,18],
"release_notes.html#qore_08123_bug_fixes":[0,73,18,0],
"release_notes.html#qore_08123_bug_fixes":[0,36,18,0],
"release_notes.html#qore_08124":[0,36,17],
"release_notes.html#qore_08124":[0,73,17],
"release_notes.html#qore_08124_bug_fixes":[0,73,17,0],
"release_notes.html#qore_08124_bug_fixes":[0,36,17,0],
"release_notes.html#qore_08125":[0,73,16],
"release_notes.html#qore_08125":[0,36,16],
"release_notes.html#qore_08125_bug_fixes":[0,73,16,1],
"release_notes.html#qore_08125_bug_fixes":[0,36,16,1],
"release_notes.html#qore_08125_new_features":[0,36,16,0],
"release_notes.html#qore_08125_new_features":[0,73,16,0],
"release_notes.html#qore_08126":[0,36,15],
"release_notes.html#qore_08126":[0,73,15],
"release_notes.html#qore_08126_bug_fixes":[0,73,15,0],
"release_notes.html#qore_08126_bug_fixes":[0,36,15,0],
"release_notes.html#qore_08127":[0,73,14],
"release_notes.html#qore_08127":[0,36,14],
"release_notes.html#qore_08127_bug_fixes":[0,36,14,0],
"release_notes.html#qore_08127_bug_fixes":[0,73,14,0],
"release_notes.html#qore_08128":[0,73,13],
"release_notes.html#qore_08128":[0,36,13],
"release_notes.html#qore_08128_bug_fixes":[0,73,13,0],
"release_notes.html#qore_08128_bug_fixes":[0,36,13,0],
"release_notes.html#qore_08129":[0,36,12],
"release_notes.html#qore_08129":[0,73,12],
"release_notes.html#qore_08129_bug_fixes":[0,36,12,0],
"release_notes.html#qore_08129_bug_fixes":[0,73,12,0],
"release_notes.html#qore_0812_bug_fixes":[0,73,21,2],
"release_notes.html#qore_0812_bug_fixes":[0,36,21,2],
"release_notes.html#qore_0812_compatibility":[0,36,21,0],
"release_notes.html#qore_0812_compatibility":[0,73,21,0],
"release_notes.html#qore_0812_new_features":[0,73,21,1],
"release_notes.html#qore_0812_new_features":[0,36,21,1],
"release_notes.html#qore_0813":[0,36,8],
"release_notes.html#qore_0813":[0,73,8],
"release_notes.html#qore_08131":[0,36,7],
"release_notes.html#qore_08131":[0,73,7],
"release_notes.html#qore_08131_bug_fixes":[0,36,7,1],
"release_notes.html#qore_08131_bug_fixes":[0,73,7,1],
"release_notes.html#qore_08131_new_features":[0,73,7,0],
"release_notes.html#qore_08131_new_features":[0,36,7,0],
"release_notes.html#qore_08132":[0,73,6],
"release_notes.html#qore_08132":[0,36,6],
"release_notes.html#qore_08132_bug_fixes":[0,73,6,1],
"release_notes.html#qore_08132_bug_fixes":[0,36,6,1],
"release_notes.html#qore_08132_new_features":[0,73,6,0],
"release_notes.html#qore_08132_new_features":[0,36,6,0],
"release_notes.html#qore_08133":[0,36,5],
"release_notes.html#qore_08133":[0,73,5],
"release_notes.html#qore_08133_bug_fixes":[0,36,5,1],
"release_notes.html#qore_08133_bug_fixes":[0,73,5,1],
"release_notes.html#qore_08133_new_features":[0,73,5,0],
"release_notes.html#qore_08133_new_features":[0,36,5,0],
"release_notes.html#qore_08134":[0,36,4],
"release_notes.html#qore_08134":[0,73,4],
"release_notes.html#qore_08134_bug_fixes":[0,36,4,0],
"release_notes.html#qore_08134_bug_fixes":[0,73,4,0],
"release_notes.html#qore_08135":[0,36,3],
"release_notes.html#qore_08135":[0,73,3],
"release_notes.html#qore_08135_bug_fixes":[0,36,3,0],
"release_notes.html#qore_08135_bug_fixes":[0,73,3,0],
"release_notes.html#qore_08136":[0,73,2],
"release_notes.html#qore_08136":[0,36,2],
"release_notes.html#qore_08136_bug_fixes":[0,36,2,0],
"release_notes.html#qore_08136_bug_fixes":[0,73,2,0],
"release_notes.html#qore_08137":[0,73,1],
"release_notes.html#qore_08137":[0,36,1],
"release_notes.html#qore_08137_bug_fixes":[0,36,1,0],
"release_notes.html#qore_08137_bug_fixes":[0,73,1,0],
"release_notes.html#qore_08138":[0,73,54],
"release_notes.html#qore_08138":[0,36,54],
"release_notes.html#qore_08138_bug_fixes":[0,36,54,0],
"release_notes.html#qore_08138_bug_fixes":[0,73,54,0],
"release_notes.html#qore_08139":[0,36,53],
"release_notes.html#qore_08139":[0,73,53],
"release_notes.html#qore_08139_bug_fixes":[0,36,53,0],
"release_notes.html#qore_08139_bug_fixes":[0,73,53,0],
"release_notes.html#qore_0813_bug_fixes":[0,73,8,2],
"release_notes.html#qore_0813_bug_fixes":[0,36,8,2],
"release_notes.html#qore_0813_compatibility":[0,73,8,0],
"release_notes.html#qore_0813_compatibility":[0,36,8,0],
"release_notes.html#qore_0813_new_features":[0,36,8,1],
"release_notes.html#qore_0813_new_features":[0,73,8,1],
"release_notes.html#qore_084":[0,36,32],
"release_notes.html#qore_084":[0,73,32],
"release_notes.html#qore_084_bug_fixes":[0,73,32,2],
"release_notes.html#qore_084_bug_fixes":[0,36,32,2],
"release_notes.html#qore_084_compatibility":[0,36,32,0],
"release_notes.html#qore_084_compatibility":[0,73,32,0],
"release_notes.html#qore_084_new_features":[0,73,32,1],
"release_notes.html#qore_084_new_features":[0,36,32,1],
"release_notes.html#qore_085":[0,73,31],
"release_notes.html#qore_085":[0,36,31],
"release_notes.html#qore_0851":[0,36,30],
"release_notes.html#qore_0851":[0,73,30],
"release_notes.html#qore_0851_bug_fixes":[0,73,30,0],
"release_notes.html#qore_0851_bug_fixes":[0,36,30,0],
"release_notes.html#qore_085_bug_fixes":[0,36,31,1],
"release_notes.html#qore_085_bug_fixes":[0,73,31,1],
"release_notes.html#qore_085_new_features":[0,73,31,0],
"release_notes.html#qore_085_new_features":[0,36,31,0],
"release_notes.html#qore_086":[0,36,29],
"release_notes.html#qore_086":[0,73,29],
"release_notes.html#qore_0861":[0,36,28],
"release_notes.html#qore_0861":[0,73,28],
"release_notes.html#qore_0861_bug_fixes":[0,73,28,1],
"release_notes.html#qore_0861_bug_fixes":[0,36,28,1],
"release_notes.html#qore_0861_changes":[0,36,28,0],
"release_notes.html#qore_0861_changes":[0,73,28,0],
"release_notes.html#qore_0862":[0,73,27],
"release_notes.html#qore_0862":[0,36,27],
"release_notes.html#qore_0862_changes":[0,73,27,1],
"release_notes.html#qore_0862_changes":[0,36,27,1],
"release_notes.html#qore_0862_compatibility":[0,73,27,0],
"release_notes.html#qore_0862_compatibility":[0,36,27,0],
"release_notes.html#qore_086_bug_fixes":[0,36,29,2],
"release_notes.html#qore_086_bug_fixes":[0,73,29,2],
"release_notes.html#qore_086_compatibility":[0,36,29,0],
"release_notes.html#qore_086_compatibility":[0,73,29,0],
"release_notes.html#qore_086_new_features":[0,36,29,1],
"release_notes.html#qore_086_new_features":[0,73,29,1],
"release_notes.html#qore_087":[0,73,26],
"release_notes.html#qore_087":[0,36,26],
"release_notes.html#qore_087_bug_fixes":[0,36,26,2],
"release_notes.html#qore_087_bug_fixes":[0,73,26,2],
"release_notes.html#qore_087_compatibility":[0,36,26,0],
"release_notes.html#qore_087_compatibility":[0,73,26,0],
"release_notes.html#qore_087_new_features":[0,36,26,1],
"release_notes.html#qore_087_new_features":[0,73,26,1],
"release_notes.html#qore_088":[0,36,25],
"release_notes.html#qore_088":[0,73,25],
"release_notes.html#qore_088_bug_fixes":[0,36,25,2],
"release_notes.html#qore_088_bug_fixes":[0,73,25,2],
"release_notes.html#qore_088_compatibility":[0,73,25,0],
"release_notes.html#qore_088_compatibility":[0,36,25,0],
"release_notes.html#qore_088_new_features":[0,36,25,1],
"release_notes.html#qore_088_new_features":[0,73,25,1],
"release_notes.html#qore_089":[0,73,24],
"release_notes.html#qore_089":[0,36,24],
"release_notes.html#qore_089_bug_fixes":[0,73,24,1],
"release_notes.html#qore_089_bug_fixes":[0,36,24,1],
"release_notes.html#qore_089_new_features":[0,36,24,0],
"release_notes.html#qore_089_new_features":[0,73,24,0],
"release_notes.html#qore_09":[0,36,0],
"release_notes.html#qore_09":[0,73,0],
"release_notes.html#qore_091":[0,36,52],
"release_notes.html#qore_091":[0,73,52],
"release_notes.html#qore_0910":[0,36,33],
"release_notes.html#qore_0910":[0,73,33],
"release_notes.html#qore_0910_bug_fixes":[0,73,33,0],
"release_notes.html#qore_0910_bug_fixes":[0,36,33,0],
"release_notes.html#qore_091_bug_fixes":[0,73,52,1],
"release_notes.html#qore_091_bug_fixes":[0,36,52,1],
"release_notes.html#qore_091_new_features":[0,36,52,0],
"release_notes.html#qore_091_new_features":[0,73,52,0],
"release_notes.html#qore_092":[0,36,51],
"release_notes.html#qore_092":[0,73,51],
"release_notes.html#qore_092_bug_fixes":[0,73,51,1],
"release_notes.html#qore_092_bug_fixes":[0,36,51,1],
"release_notes.html#qore_092_new_features":[0,36,51,0],
"release_notes.html#qore_092_new_features":[0,73,51,0],
"release_notes.html#qore_093":[0,36,50],
"release_notes.html#qore_093":[0,73,50],
"release_notes.html#qore_0931":[0,36,49],
"release_notes.html#qore_0931":[0,73,49],
"release_notes.html#qore_0931_bug_fixes":[0,36,49,0],
"release_notes.html#qore_0931_bug_fixes":[0,73,49,0],
"release_notes.html#qore_0932":[0,73,48],
"release_notes.html#qore_0932":[0,36,48],
"release_notes.html#qore_0932_bug_fixes":[0,73,48,1],
"release_notes.html#qore_0932_bug_fixes":[0,36,48,1],
"release_notes.html#qore_0932_new_features":[0,73,48,0],
"release_notes.html#qore_0932_new_features":[0,36,48,0],
"release_notes.html#qore_0933":[0,73,47],
"release_notes.html#qore_0933":[0,36,47],
"release_notes.html#qore_0933_bug_fixes":[0,36,47,0],
"release_notes.html#qore_0933_bug_fixes":[0,73,47,0],
"release_notes.html#qore_093_bug_fixes":[0,36,50,2],
"release_notes.html#qore_093_bug_fixes":[0,73,50,2],
"release_notes.html#qore_093_compatibility":[0,73,50,0],
"release_notes.html#qore_093_compatibility":[0,36,50,0],
"release_notes.html#qore_093_new_features":[0,73,50,1],
"release_notes.html#qore_093_new_features":[0,36,50,1],
"release_notes.html#qore_094":[0,36,46],
"release_notes.html#qore_094":[0,73,46],
"release_notes.html#qore_0941":[0,36,45],
"release_notes.html#qore_0941":[0,73,45],
"release_notes.html#qore_0941_bug_fixes":[0,73,45,1],
"release_notes.html#qore_0941_bug_fixes":[0,36,45,1],
"release_notes.html#qore_0941_new_features":[0,36,45,0],
"release_notes.html#qore_0941_new_features":[0,73,45,0],
"release_notes.html#qore_0942":[0,36,44],
"release_notes.html#qore_0942":[0,73,44],
"release_notes.html#qore_0942_bug_fixes":[0,36,44,1],
"release_notes.html#qore_0942_bug_fixes":[0,73,44,1],
"release_notes.html#qore_0942_new_features":[0,36,44,0],
"release_notes.html#qore_0942_new_features":[0,73,44,0],
"release_notes.html#qore_0943":[0,73,43],
"release_notes.html#qore_0943":[0,36,43],
"release_notes.html#qore_0943_bug_fixes":[0,36,43,1],
"release_notes.html#qore_0943_bug_fixes":[0,73,43,1],
"release_notes.html#qore_0943_new_features":[0,36,43,0],
"release_notes.html#qore_0943_new_features":[0,73,43,0],
"release_notes.html#qore_0944":[0,36,42],
"release_notes.html#qore_0944":[0,73,42],
"release_notes.html#qore_0944_bug_fixes":[0,36,42,1],
"release_notes.html#qore_0944_bug_fixes":[0,73,42,1],
"release_notes.html#qore_0944_new_features":[0,36,42,0],
"release_notes.html#qore_0944_new_features":[0,73,42,0],
"release_notes.html#qore_0945":[0,36,41],
"release_notes.html#qore_0945":[0,73,41],
"release_notes.html#qore_0945_bug_fixes":[0,73,41,1],
"release_notes.html#qore_0945_bug_fixes":[0,36,41,1],
"release_notes.html#qore_0945_new_features":[0,36,41,0],
"release_notes.html#qore_0945_new_features":[0,73,41,0],
"release_notes.html#qore_0946":[0,36,40],
"release_notes.html#qore_0946":[0,73,40],
"release_notes.html#qore_0946_bug_fixesd":[0,36,40,0],
"release_notes.html#qore_0946_bug_fixesd":[0,73,40,0],
"release_notes.html#qore_0947":[0,73,39],
"release_notes.html#qore_0947":[0,36,39]
};

==> qore-0.9.11.tar.bz2: qore-0.9.11/docs/lang/html/navtreeindex15.js <==
var NAVTREEINDEX15 =
{
"qore_modules.html#mod_overview":[0,41,0],
"qore_modules.html#mod_public":[0,41,2,1],
"qore_modules.html#mod_public":[0,4,2,1],
"qore_modules.html#user_module_declarations":[0,41,2,0],
"qore_modules.html#user_module_declarations":[0,4,2,0],
"qore_modules.html#user_module_program_scope":[0,41,2,3],
"qore_modules.html#user_module_program_scope":[0,4,2,3],
"qore_modules.html#user_modules":[0,41,2],
"qore_modules.html#user_modules":[0,4,2],
"qore_namespaces.html":[0,24],
"qore_namespaces.html":[0,61],
"qore_regex.html":[0,19],
"qore_regex.html":[0,56],
"qore_regex.html#qore_regex_backreferences":[0,19,2,0],
"qore_regex.html#qore_regex_backreferences":[0,56,2,0],
"qore_regex.html#qore_regex_functions":[0,56,2],
"qore_regex.html#qore_regex_functions":[0,19,2],
"qore_regex.html#qore_regex_intro":[0,56,0],
"qore_regex.html#qore_regex_intro":[0,19,0],
"qore_regex.html#qore_regex_operators":[0,56,1],
"qore_regex.html#qore_regex_operators":[0,19,1],
"qore_regex.html#qore_regex_options":[0,19,1,0],
"qore_regex.html#qore_regex_options":[0,56,1,0],
"release_notes.html":[0,36],
"release_notes.html":[0,73],
"release_notes.html#qore_0810":[0,73,23],
"release_notes.html#qore_0810":[0,36,23],
"release_notes.html#qore_0810_bug_fixes":[0,73,23,1],
"release_notes.html#qore_0810_bug_fixes":[0,36,23,1],
"release_notes.html#qore_0810_new_features":[0,36,23,0],
"release_notes.html#qore_0810_new_features":[0,73,23,0],
"release_notes.html#qore_0811":[0,73,22],
"release_notes.html#qore_0811":[0,36,22],
"release_notes.html#qore_0811_bug_fixes":[0,36,22,1],
"release_notes.html#qore_0811_bug_fixes":[0,73,22,1],
"release_notes.html#qore_0811_new_features":[0,36,22,0],
"release_notes.html#qore_0811_new_features":[0,73,22,0],
"release_notes.html#qore_0812":[0,36,21],
"release_notes.html#qore_0812":[0,73,21],
"release_notes.html#qore_08121":[0,73,20],
"release_notes.html#qore_08121":[0,36,20],
"release_notes.html#qore_081210":[0,73,11],
"release_notes.html#qore_081210":[0,36,11],
"release_notes.html#qore_081210_bug_fixes":[0,73,11,0],
"release_notes.html#qore_081210_bug_fixes":[0,36,11,0],
"release_notes.html#qore_081211":[0,36,10],
"release_notes.html#qore_081211":[0,73,10],
"release_notes.html#qore_081211_bug_fixes":[0,73,10,1],
"release_notes.html#qore_081211_bug_fixes":[0,36,10,1],
"release_notes.html#qore_081211_new_features":[0,36,10,0],
"release_notes.html#qore_081211_new_features":[0,73,10,0],
"release_notes.html#qore_081212":[0,36,9],
"release_notes.html#qore_081212":[0,73,9],
"release_notes.html#qore_081212_bug_fixes":[0,73,9,1],
"release_notes.html#qore_081212_bug_fixes":[0,36,9,1],
"release_notes.html#qore_081212_new_features":[0,73,9,0],
"release_notes.html#qore_081212_new_features":[0,36,9,0],
"release_notes.html#qore_08121_bug_fixes":[0,36,20,0],
"release_notes.html#qore_08121_bug_fixes":[0,73,20,0],
"release_notes.html#qore_08122":[0,73,19],
"release_notes.html#qore_08122":[0,36,19],
"release_notes.html#qore_08122_bug_fixes":[0,73,19,0],
"release_notes.html#qore_08122_bug_fixes":[0,36,19,0],
"release_notes.html#qore_08123":[0,73,18],
"release_notes.html#qore_08123":[0,36,18],
"release_notes.html#qore_08123_bug_fixes":[0,73,18,0],
"release_notes.html#qore_08123_bug_fixes":[0,36,18,0],
"release_notes.html#qore_08124":[0,73,17],
"release_notes.html#qore_08124":[0,36,17],
"release_notes.html#qore_08124_bug_fixes":[0,36,17,0],
"release_notes.html#qore_08124_bug_fixes":[0,73,17,0],
"release_notes.html#qore_08125":[0,73,16],
"release_notes.html#qore_08125":[0,36,16],
"release_notes.html#qore_08125_bug_fixes":[0,36,16,1],
"release_notes.html#qore_08125_bug_fixes":[0,73,16,1],
"release_notes.html#qore_08125_new_features":[0,36,16,0],
"release_notes.html#qore_08125_new_features":[0,73,16,0],
"release_notes.html#qore_08126":[0,73,15],
"release_notes.html#qore_08126":[0,36,15],
"release_notes.html#qore_08126_bug_fixes":[0,73,15,0],
"release_notes.html#qore_08126_bug_fixes":[0,36,15,0],
"release_notes.html#qore_08127":[0,36,14],
"release_notes.html#qore_08127":[0,73,14],
"release_notes.html#qore_08127_bug_fixes":[0,73,14,0],
"release_notes.html#qore_08127_bug_fixes":[0,36,14,0],
"release_notes.html#qore_08128":[0,73,13],
"release_notes.html#qore_08128":[0,36,13],
"release_notes.html#qore_08128_bug_fixes":[0,36,13,0],
"release_notes.html#qore_08128_bug_fixes":[0,73,13,0],
"release_notes.html#qore_08129":[0,73,12],
"release_notes.html#qore_08129":[0,36,12],
"release_notes.html#qore_08129_bug_fixes":[0,73,12,0],
"release_notes.html#qore_08129_bug_fixes":[0,36,12,0],
"release_notes.html#qore_0812_bug_fixes":[0,73,21,2],
"release_notes.html#qore_0812_bug_fixes":[0,36,21,2],
"release_notes.html#qore_0812_compatibility":[0,36,21,0],
"release_notes.html#qore_0812_compatibility":[0,73,21,0],
"release_notes.html#qore_0812_new_features":[0,73,21,1],
"release_notes.html#qore_0812_new_features":[0,36,21,1],
"release_notes.html#qore_0813":[0,36,8],
"release_notes.html#qore_0813":[0,73,8],
"release_notes.html#qore_08131":[0,36,7],
"release_notes.html#qore_08131":[0,73,7],
"release_notes.html#qore_08131_bug_fixes":[0,73,7,1],
"release_notes.html#qore_08131_bug_fixes":[0,36,7,1],
"release_notes.html#qore_08131_new_features":[0,73,7,0],
"release_notes.html#qore_08131_new_features":[0,36,7,0],
"release_notes.html#qore_08132":[0,36,6],
"release_notes.html#qore_08132":[0,73,6],
"release_notes.html#qore_08132_bug_fixes":[0,36,6,1],
"release_notes.html#qore_08132_bug_fixes":[0,73,6,1],
"release_notes.html#qore_08132_new_features":[0,36,6,0],
"release_notes.html#qore_08132_new_features":[0,73,6,0],
"release_notes.html#qore_08133":[0,73,5],
"release_notes.html#qore_08133":[0,36,5],
"release_notes.html#qore_08133_bug_fixes":[0,36,5,1],
"release_notes.html#qore_08133_bug_fixes":[0,73,5,1],
"release_notes.html#qore_08133_new_features":[0,36,5,0],
"release_notes.html#qore_08133_new_features":[0,73,5,0],
"release_notes.html#qore_08134":[0,36,4],
"release_notes.html#qore_08134":[0,73,4],
"release_notes.html#qore_08134_bug_fixes":[0,36,4,0],
"release_notes.html#qore_08134_bug_fixes":[0,73,4,0],
"release_notes.html#qore_08135":[0,73,3],
"release_notes.html#qore_08135":[0,36,3],
"release_notes.html#qore_08135_bug_fixes":[0,36,3,0],
"release_notes.html#qore_08135_bug_fixes":[0,73,3,0],
"release_notes.html#qore_08136":[0,36,2],
"release_notes.html#qore_08136":[0,73,2],
"release_notes.html#qore_08136_bug_fixes":[0,73,2,0],
"release_notes.html#qore_08136_bug_fixes":[0,36,2,0],
"release_notes.html#qore_08137":[0,36,1],
"release_notes.html#qore_08137":[0,73,1],
"release_notes.html#qore_08137_bug_fixes":[0,73,1,0],
"release_notes.html#qore_08137_bug_fixes":[0,36,1,0],
"release_notes.html#qore_08138":[0,73,55],
"release_notes.html#qore_08138":[0,36,55],
"release_notes.html#qore_08138_bug_fixes":[0,36,55,0],
"release_notes.html#qore_08138_bug_fixes":[0,73,55,0],
"release_notes.html#qore_08139":[0,36,54],
"release_notes.html#qore_08139":[0,73,54],
"release_notes.html#qore_08139_bug_fixes":[0,36,54,0],
"release_notes.html#qore_08139_bug_fixes":[0,73,54,0],
"release_notes.html#qore_0813_bug_fixes":[0,36,8,2],
"release_notes.html#qore_0813_bug_fixes":[0,73,8,2],
"release_notes.html#qore_0813_compatibility":[0,73,8,0],
"release_notes.html#qore_0813_compatibility":[0,36,8,0],
"release_notes.html#qore_0813_new_features":[0,36,8,1],
"release_notes.html#qore_0813_new_features":[0,73,8,1],
"release_notes.html#qore_084":[0,73,32],
"release_notes.html#qore_084":[0,36,32],
"release_notes.html#qore_084_bug_fixes":[0,73,32,2],
"release_notes.html#qore_084_bug_fixes":[0,36,32,2],
"release_notes.html#qore_084_compatibility":[0,36,32,0],
"release_notes.html#qore_084_compatibility":[0,73,32,0],
"release_notes.html#qore_084_new_features":[0,73,32,1],
"release_notes.html#qore_084_new_features":[0,36,32,1],
"release_notes.html#qore_085":[0,36,31],
"release_notes.html#qore_085":[0,73,31],
"release_notes.html#qore_0851":[0,36,30],
"release_notes.html#qore_0851":[0,73,30],
"release_notes.html#qore_0851_bug_fixes":[0,73,30,0],
"release_notes.html#qore_0851_bug_fixes":[0,36,30,0],
"release_notes.html#qore_085_bug_fixes":[0,73,31,1],
"release_notes.html#qore_085_bug_fixes":[0,36,31,1],
"release_notes.html#qore_085_new_features":[0,36,31,0],
"release_notes.html#qore_085_new_features":[0,73,31,0],
"release_notes.html#qore_086":[0,73,29],
"release_notes.html#qore_086":[0,36,29],
"release_notes.html#qore_0861":[0,73,28],
"release_notes.html#qore_0861":[0,36,28],
"release_notes.html#qore_0861_bug_fixes":[0,73,28,1],
"release_notes.html#qore_0861_bug_fixes":[0,36,28,1],
"release_notes.html#qore_0861_changes":[0,73,28,0],
"release_notes.html#qore_0861_changes":[0,36,28,0],
"release_notes.html#qore_0862":[0,73,27],
"release_notes.html#qore_0862":[0,36,27],
"release_notes.html#qore_0862_changes":[0,36,27,1],
"release_notes.html#qore_0862_changes":[0,73,27,1],
"release_notes.html#qore_0862_compatibility":[0,73,27,0],
"release_notes.html#qore_0862_compatibility":[0,36,27,0],
"release_notes.html#qore_086_bug_fixes":[0,73,29,2],
"release_notes.html#qore_086_bug_fixes":[0,36,29,2],
"release_notes.html#qore_086_compatibility":[0,73,29,0],
"release_notes.html#qore_086_compatibility":[0,36,29,0],
"release_notes.html#qore_086_new_features":[0,36,29,1],
"release_notes.html#qore_086_new_features":[0,73,29,1],
"release_notes.html#qore_087":[0,73,26],
"release_notes.html#qore_087":[0,36,26],
"release_notes.html#qore_087_bug_fixes":[0,36,26,2],
"release_notes.html#qore_087_bug_fixes":[0,73,26,2],
"release_notes.html#qore_087_compatibility":[0,36,26,0],
"release_notes.html#qore_087_compatibility":[0,73,26,0],
"release_notes.html#qore_087_new_features":[0,73,26,1],
"release_notes.html#qore_087_new_features":[0,36,26,1],
"release_notes.html#qore_088":[0,73,25],
"release_notes.html#qore_088":[0,36,25],
"release_notes.html#qore_088_bug_fixes":[0,73,25,2],
"release_notes.html#qore_088_bug_fixes":[0,36,25,2],
"release_notes.html#qore_088_compatibility":[0,36,25,0],
"release_notes.html#qore_088_compatibility":[0,73,25,0],
"release_notes.html#qore_088_new_features":[0,73,25,1],
"release_notes.html#qore_088_new_features":[0,36,25,1],
"release_notes.html#qore_089":[0,36,24],
"release_notes.html#qore_089":[0,73,24],
"release_notes.html#qore_089_bug_fixes":[0,73,24,1],
"release_notes.html#qore_089_bug_fixes":[0,36,24,1],
"release_notes.html#qore_089_new_features":[0,73,24,0],
"release_notes.html#qore_089_new_features":[0,36,24,0],
"release_notes.html#qore_09":[0,73,0],
"release_notes.html#qore_09":[0,36,0],
"release_notes.html#qore_091":[0,36,53],
"release_notes.html#qore_091":[0,73,53],
"release_notes.html#qore_0910":[0,36,34],
"release_notes.html#qore_0910":[0,73,34],
"release_notes.html#qore_0910_bug_fixes":[0,36,34,1],
"release_notes.html#qore_0910_bug_fixes":[0,73,34,1],
"release_notes.html#qore_0910_new_modules":[0,73,34,0],
"release_notes.html#qore_0910_new_modules":[0,36,34,0],
"release_notes.html#qore_0911":[0,73,33],
"release_notes.html#qore_0911":[0,36,33],
"release_notes.html#qore_0911_bug_fixes":[0,36,33,0],
"release_notes.html#qore_0911_bug_fixes":[0,73,33,0],
"release_notes.html#qore_091_bug_fixes":[0,73,53,1],
"release_notes.html#qore_091_bug_fixes":[0,36,53,1],
"release_notes.html#qore_091_new_features":[0,36,53,0],
"release_notes.html#qore_091_new_features":[0,73,53,0],
"release_notes.html#qore_092":[0,36,52],
"release_notes.html#qore_092":[0,73,52],
"release_notes.html#qore_092_bug_fixes":[0,73,52,1],
"release_notes.html#qore_092_bug_fixes":[0,36,52,1],
"release_notes.html#qore_092_new_features":[0,73,52,0],
"release_notes.html#qore_092_new_features":[0,36,52,0],
"release_notes.html#qore_093":[0,73,51],
"release_notes.html#qore_093":[0,36,51],
"release_notes.html#qore_0931":[0,73,50],
"release_notes.html#qore_0931":[0,36,50],
"release_notes.html#qore_0931_bug_fixes":[0,73,50,0],
"release_notes.html#qore_0931_bug_fixes":[0,36,50,0],
"release_notes.html#qore_0932":[0,73,49],
"release_notes.html#qore_0932":[0,36,49],
"release_notes.html#qore_0932_bug_fixes":[0,36,49,1],
"release_notes.html#qore_0932_bug_fixes":[0,73,49,1],
"release_notes.html#qore_0932_new_features":[0,73,49,0],
"release_notes.html#qore_0932_new_features":[0,36,49,0],
"release_notes.html#qore_0933":[0,36,48],
"release_notes.html#qore_0933":[0,73,48],
"release_notes.html#qore_0933_bug_fixes":[0,73,48,0],
"release_notes.html#qore_0933_bug_fixes":[0,36,48,0],
"release_notes.html#qore_093_bug_fixes":[0,36,51,2]
};
